@@ -13,7 +13,7 @@ Usage::
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 import sys
-from typing import Any, Dict, IO, List, TYPE_CHECKING, Union, overload
+from typing import Any, Dict, IO, List, TYPE_CHECKING, Type, Union, overload
 from botocore.exceptions import ClientError as Boto3ClientError
 from mypy_boto3_secretsmanager.paginator import ListSecretsPaginator
 from mypy_boto3_secretsmanager.type_defs import (
@@ -47,35 +47,35 @@ __all__ = ("SecretsManagerClient",)
 
 
 class Exceptions:
-    ClientError: Boto3ClientError
-    DecryptionFailure: Boto3ClientError
-    EncryptionFailure: Boto3ClientError
-    InternalServiceError: Boto3ClientError
-    InvalidNextTokenException: Boto3ClientError
-    InvalidParameterException: Boto3ClientError
-    InvalidRequestException: Boto3ClientError
-    LimitExceededException: Boto3ClientError
-    MalformedPolicyDocumentException: Boto3ClientError
-    PreconditionNotMetException: Boto3ClientError
-    ResourceExistsException: Boto3ClientError
-    ResourceNotFoundException: Boto3ClientError
+    ClientError: Type[Boto3ClientError]
+    DecryptionFailure: Type[Boto3ClientError]
+    EncryptionFailure: Type[Boto3ClientError]
+    InternalServiceError: Type[Boto3ClientError]
+    InvalidNextTokenException: Type[Boto3ClientError]
+    InvalidParameterException: Type[Boto3ClientError]
+    InvalidRequestException: Type[Boto3ClientError]
+    LimitExceededException: Type[Boto3ClientError]
+    MalformedPolicyDocumentException: Type[Boto3ClientError]
+    PreconditionNotMetException: Type[Boto3ClientError]
+    ResourceExistsException: Type[Boto3ClientError]
+    ResourceNotFoundException: Type[Boto3ClientError]
 
 
 class SecretsManagerClient:
     """
-    [SecretsManager.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.27/reference/services/secretsmanager.html#SecretsManager.Client)
+    [SecretsManager.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.29/reference/services/secretsmanager.html#SecretsManager.Client)
     """
 
     exceptions: Exceptions
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.27/reference/services/secretsmanager.html#SecretsManager.Client.can_paginate)
+        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.29/reference/services/secretsmanager.html#SecretsManager.Client.can_paginate)
         """
 
     def cancel_rotate_secret(self, SecretId: str) -> CancelRotateSecretResponseTypeDef:
         """
-        [Client.cancel_rotate_secret documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.27/reference/services/secretsmanager.html#SecretsManager.Client.cancel_rotate_secret)
+        [Client.cancel_rotate_secret documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.29/reference/services/secretsmanager.html#SecretsManager.Client.cancel_rotate_secret)
         """
 
     def create_secret(
@@ -89,12 +89,12 @@ class SecretsManagerClient:
         Tags: List[TagTypeDef] = None,
     ) -> CreateSecretResponseTypeDef:
         """
-        [Client.create_secret documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.27/reference/services/secretsmanager.html#SecretsManager.Client.create_secret)
+        [Client.create_secret documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.29/reference/services/secretsmanager.html#SecretsManager.Client.create_secret)
         """
 
     def delete_resource_policy(self, SecretId: str) -> DeleteResourcePolicyResponseTypeDef:
         """
-        [Client.delete_resource_policy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.27/reference/services/secretsmanager.html#SecretsManager.Client.delete_resource_policy)
+        [Client.delete_resource_policy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.29/reference/services/secretsmanager.html#SecretsManager.Client.delete_resource_policy)
         """
 
     def delete_secret(
@@ -104,12 +104,12 @@ class SecretsManagerClient:
         ForceDeleteWithoutRecovery: bool = None,
     ) -> DeleteSecretResponseTypeDef:
         """
-        [Client.delete_secret documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.27/reference/services/secretsmanager.html#SecretsManager.Client.delete_secret)
+        [Client.delete_secret documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.29/reference/services/secretsmanager.html#SecretsManager.Client.delete_secret)
         """
 
     def describe_secret(self, SecretId: str) -> DescribeSecretResponseTypeDef:
         """
-        [Client.describe_secret documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.27/reference/services/secretsmanager.html#SecretsManager.Client.describe_secret)
+        [Client.describe_secret documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.29/reference/services/secretsmanager.html#SecretsManager.Client.describe_secret)
         """
 
     def generate_presigned_url(
@@ -120,7 +120,7 @@ class SecretsManagerClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.27/reference/services/secretsmanager.html#SecretsManager.Client.generate_presigned_url)
+        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.29/reference/services/secretsmanager.html#SecretsManager.Client.generate_presigned_url)
         """
 
     def get_random_password(
@@ -135,19 +135,19 @@ class SecretsManagerClient:
         RequireEachIncludedType: bool = None,
     ) -> GetRandomPasswordResponseTypeDef:
         """
-        [Client.get_random_password documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.27/reference/services/secretsmanager.html#SecretsManager.Client.get_random_password)
+        [Client.get_random_password documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.29/reference/services/secretsmanager.html#SecretsManager.Client.get_random_password)
         """
 
     def get_resource_policy(self, SecretId: str) -> GetResourcePolicyResponseTypeDef:
         """
-        [Client.get_resource_policy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.27/reference/services/secretsmanager.html#SecretsManager.Client.get_resource_policy)
+        [Client.get_resource_policy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.29/reference/services/secretsmanager.html#SecretsManager.Client.get_resource_policy)
         """
 
     def get_secret_value(
         self, SecretId: str, VersionId: str = None, VersionStage: str = None
     ) -> GetSecretValueResponseTypeDef:
         """
-        [Client.get_secret_value documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.27/reference/services/secretsmanager.html#SecretsManager.Client.get_secret_value)
+        [Client.get_secret_value documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.29/reference/services/secretsmanager.html#SecretsManager.Client.get_secret_value)
         """
 
     def list_secret_version_ids(
@@ -158,21 +158,21 @@ class SecretsManagerClient:
         IncludeDeprecated: bool = None,
     ) -> ListSecretVersionIdsResponseTypeDef:
         """
-        [Client.list_secret_version_ids documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.27/reference/services/secretsmanager.html#SecretsManager.Client.list_secret_version_ids)
+        [Client.list_secret_version_ids documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.29/reference/services/secretsmanager.html#SecretsManager.Client.list_secret_version_ids)
         """
 
     def list_secrets(
         self, MaxResults: int = None, NextToken: str = None
     ) -> ListSecretsResponseTypeDef:
         """
-        [Client.list_secrets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.27/reference/services/secretsmanager.html#SecretsManager.Client.list_secrets)
+        [Client.list_secrets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.29/reference/services/secretsmanager.html#SecretsManager.Client.list_secrets)
         """
 
     def put_resource_policy(
         self, SecretId: str, ResourcePolicy: str
     ) -> PutResourcePolicyResponseTypeDef:
         """
-        [Client.put_resource_policy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.27/reference/services/secretsmanager.html#SecretsManager.Client.put_resource_policy)
+        [Client.put_resource_policy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.29/reference/services/secretsmanager.html#SecretsManager.Client.put_resource_policy)
         """
 
     def put_secret_value(
@@ -184,12 +184,12 @@ class SecretsManagerClient:
         VersionStages: List[str] = None,
     ) -> PutSecretValueResponseTypeDef:
         """
-        [Client.put_secret_value documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.27/reference/services/secretsmanager.html#SecretsManager.Client.put_secret_value)
+        [Client.put_secret_value documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.29/reference/services/secretsmanager.html#SecretsManager.Client.put_secret_value)
         """
 
     def restore_secret(self, SecretId: str) -> RestoreSecretResponseTypeDef:
         """
-        [Client.restore_secret documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.27/reference/services/secretsmanager.html#SecretsManager.Client.restore_secret)
+        [Client.restore_secret documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.29/reference/services/secretsmanager.html#SecretsManager.Client.restore_secret)
         """
 
     def rotate_secret(
@@ -200,17 +200,17 @@ class SecretsManagerClient:
         RotationRules: RotationRulesTypeTypeDef = None,
     ) -> RotateSecretResponseTypeDef:
         """
-        [Client.rotate_secret documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.27/reference/services/secretsmanager.html#SecretsManager.Client.rotate_secret)
+        [Client.rotate_secret documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.29/reference/services/secretsmanager.html#SecretsManager.Client.rotate_secret)
         """
 
     def tag_resource(self, SecretId: str, Tags: List[TagTypeDef]) -> None:
         """
-        [Client.tag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.27/reference/services/secretsmanager.html#SecretsManager.Client.tag_resource)
+        [Client.tag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.29/reference/services/secretsmanager.html#SecretsManager.Client.tag_resource)
         """
 
     def untag_resource(self, SecretId: str, TagKeys: List[str]) -> None:
         """
-        [Client.untag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.27/reference/services/secretsmanager.html#SecretsManager.Client.untag_resource)
+        [Client.untag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.29/reference/services/secretsmanager.html#SecretsManager.Client.untag_resource)
         """
 
     def update_secret(
@@ -223,7 +223,7 @@ class SecretsManagerClient:
         SecretString: str = None,
     ) -> UpdateSecretResponseTypeDef:
         """
-        [Client.update_secret documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.27/reference/services/secretsmanager.html#SecretsManager.Client.update_secret)
+        [Client.update_secret documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.29/reference/services/secretsmanager.html#SecretsManager.Client.update_secret)
         """
 
     def update_secret_version_stage(
@@ -234,11 +234,11 @@ class SecretsManagerClient:
         MoveToVersionId: str = None,
     ) -> UpdateSecretVersionStageResponseTypeDef:
         """
-        [Client.update_secret_version_stage documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.27/reference/services/secretsmanager.html#SecretsManager.Client.update_secret_version_stage)
+        [Client.update_secret_version_stage documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.29/reference/services/secretsmanager.html#SecretsManager.Client.update_secret_version_stage)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_secrets"]) -> ListSecretsPaginator:
         """
-        [Paginator.ListSecrets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.27/reference/services/secretsmanager.html#SecretsManager.Paginator.ListSecrets)
+        [Paginator.ListSecrets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.29/reference/services/secretsmanager.html#SecretsManager.Paginator.ListSecrets)
         """
